@@ -1,6 +1,6 @@
-package WWW::AdventCalendar::Article;
+package WWW::AdventCalendar::Article 1.113;
 # ABSTRACT: one article in an advent calendar
-$WWW::AdventCalendar::Article::VERSION = '1.112';
+
 use Moose;
 
 #pod =head1 DESCRIPTION
@@ -179,7 +179,7 @@ WWW::AdventCalendar::Article - one article in an advent calendar
 
 =head1 VERSION
 
-version 1.112
+version 1.113
 
 =head1 DESCRIPTION
 
@@ -187,6 +187,18 @@ Objects of this class represent a single article in a L<WWW::AdventCalendar>.
 They have a very limited set of attributes.  The primary task of this class is
 the production of an HTML version of the article's body.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 date
@@ -236,11 +248,11 @@ appear to be a mailbox string, the whole value is returned.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
