@@ -1,6 +1,6 @@
-package WWW::AdventCalendar::Config;
+package WWW::AdventCalendar::Config 1.113;
 # ABSTRACT: Config::MVP-based configuration reader for WWW::AdventCalendar
-$WWW::AdventCalendar::Config::VERSION = '1.112';
+
 use Moose;
 extends 'Config::MVP::Reader::INI';
 
@@ -65,7 +65,7 @@ WWW::AdventCalendar::Config - Config::MVP-based configuration reader for WWW::Ad
 
 =head1 VERSION
 
-version 1.112
+version 1.113
 
 =head1 DESCRIPTION
 
@@ -77,13 +77,25 @@ pre-configured.
 
 Apart from that, there is nothing to say.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
